#include <MQ135.h>
#include <time.h>




// Make sure to include Onewire and Dallas Temperature libraries
#include <OneWire.h>
#include <DallasTemperature.h>




/*  MQ135 gas sensor
    Datasheet can be found here: https://www.olimex.com/Products/Components/Sensors/SNS-MQ135/resources/SNS-MQ135.pdf


    Application
    They are used in air quality control equipments for buildings/offices, are suitable for detecting of NH3, NOx, alcohol, Benzene, smoke, CO2, etc




    Original creator of this library: https://github.com/GeorgK/MQ135
*/


//sets pin for batch temperature sensor and CO2 sensor
#define PIN_MQ135 A0
#define batchTemp 7


MQ135 mq135_sensor(PIN_MQ135);


OneWire ds18x20[] = {batchTemp};


const int oneWireCount = sizeof(ds18x20) / sizeof(OneWire);
DallasTemperature sensor[oneWireCount];


float temperature = 21.1; // Assume current temperature.
float humidity = 71.0; // Assume current humidity. 
float times;




void setup() {
  Serial.begin(9600);
  Serial.println("Warming Up MQ135");
  delay(3000);
  Serial.println("time (min): \t T_Batch (deg F) \t Corrected RZero:  \t CO2_1 (ppm)");


// Start up the library on all defined bus-wires
   DeviceAddress deviceAddress;
  for (int i = 0; i < oneWireCount; i++) {
    sensor[i].setOneWire(&ds18x20[i]);
    sensor[i].begin();
    if (sensor[i].getAddress(deviceAddress, 0)) sensor[i].setResolution(deviceAddress, 12);
  }
}


void loop() {
for (int i = 0; i < oneWireCount; i++) {
    sensor[i].requestTemperatures();
  }
  times = (millis()/1000.0)/60.0;
  float correctedRZero = mq135_sensor.getCorrectedRZero(temperature, humidity);
  float correctedPPM = mq135_sensor.getCorrectedPPM(temperature, humidity);




 Serial.print(times);
 Serial.print ("\t");
for (int i = 0; i < oneWireCount; i++) {
    float temperature = sensor[i].getTempFByIndex(0);
    Serial.print(temperature);
    Serial.print("\t");
 
  Serial.print(correctedRZero);
  Serial.print("\t");
  Serial.print(correctedPPM);
  Serial.println("ppm");
  delay(1000);


 
}
}










